//
//  ViewController.m
//  MTOneObjCSample
//
//  Created by John McKnight on 10/22/14.
//  Copyright (c) 2014 Media Tuners LLC. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
    
    self.sharedSDK = [MTOneSDK sharedInstance];
    self.currentUri = @"";
    self.last_welcome = @"";
}


- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}


- (void)viewDidAppear:(BOOL)animated {
    [super viewDidAppear:animated];
    
    self.webView.delegate = self;
    
    self.sharedSDK.apiKey = @"YOUR API KEY";
    
    [self.label setText:@"Logging In"];
    
    [self.sharedSDK authLogin:@"anonymous" password:@"" completion:^(ServerResponse * response) {
        if (response.success) {
            [self.label setText:@"Scanning"];
        
            [[NSNotificationCenter defaultCenter] addObserver:self
                                                     selector:@selector(proximtyGetSuccess:)
                                                         name:@"proximtyGetSuccess"
                                                       object:nil];
            
            
            [[NSNotificationCenter defaultCenter] addObserver:self
                                                     selector:@selector(beaconUpdated:)
                                                         name:@"beaconUpdated"
                                                       object:nil];

            [self.sharedSDK callProximityListAndStartBluetooth];
        } else {
            [self.label setText:@"Could not login. Check your API key."];
        }
    }];
}


-(void)proximtyGetSuccess:(NSNotification *)notification {
    dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_BACKGROUND, 0), ^ {
        NSString * welcome = [self.sharedSDK getInfoValueForKey:@"place_welcome"];
        
        if ([welcome isEqualToString:@""] == false) {
            if ([welcome isEqualToString:self.last_welcome] == false) {
                [self.sharedSDK sendLocalNotification:welcome];
                self.last_welcome = welcome;
            }
        }

        NSDictionary * actions = [self.sharedSDK getActionsForNearestBeacon];

        if (actions.count != 0) {
            [self.sharedSDK sendNearestBeaconAsLocalNotification];
            
            
            for (NSString* key in actions) {
                id action = [actions objectForKey:key];
                @try {
                    NSString * mime_type = [action[@"mime_type"] asString];

                    if ([mime_type isEqualToString:@"text/html"]) {
                        NSString *uri = [action[@"uri"] asString];
                        [self openWebPage:uri];
                    }
                }
                @catch (NSException *exception) {
                }
                @finally {
                }
            }
        }
    });
}


-(void)openWebPage:(NSString*) uri {
    if ([uri isEqualToString:@""]) {
        return;
    }
    
    // Don't reload this page.
    if ([uri isEqualToString:self.currentUri]) {
        return;
    }
    
    self.currentUri = uri;
        
    NSURL *url = [[NSURL alloc] initWithString:uri];
    NSURLRequest *request = [[NSURLRequest alloc] initWithURL:url];
    
    [self.webView loadRequest:request];
}


-(void)beaconUpdated:(NSNotification *)notification {
    NSString * proximity = [self.sharedSDK getBeaconProximityAsString:self.sharedSDK.nearestBeacon];
    
    MTOnePlace *place = self.sharedSDK.currentPlaceInfo.places[0];
    
    NSString * message = [NSString stringWithFormat:@"Major: %@ Minor: %@ RSSI:%ld Proximity: %@ Accuracy: %f Lat: %f Lng: %f", self.sharedSDK.nearestBeacon.major, self.sharedSDK.nearestBeacon.minor, (long)self.sharedSDK.nearestBeacon.rssi, proximity, self.sharedSDK.nearestBeacon.accuracy, place.place_point.lat, place.place_point.lng];
    
    [self.label setText:message];
}


- (BOOL)webView:(UIWebView*)webView shouldStartLoadWithRequest:(NSURLRequest*)request navigationType:(UIWebViewNavigationType)navigationType {
    return YES;
}


- (void)webViewDidStartLoad:(UIWebView *)webView
{
    [[UIApplication sharedApplication] setNetworkActivityIndicatorVisible:YES];
}


- (void)webViewDidFinishLoad:(UIWebView *)webView {
    [[UIApplication sharedApplication] setNetworkActivityIndicatorVisible:NO];
}


- (void)webView:(UIWebView *)webView didFailLoadWithError:(NSError *)error {
    [[UIApplication sharedApplication] setNetworkActivityIndicatorVisible:NO];
    
    NSLog(@"%@", error);
}

@end
