//
//  ViewController.swift
//  MTOneSwiftSample
//
//  Created by John McKnight on 8/28/14.
//  Copyright (c) 2014 Media Tuners LLC. All rights reserved.
//

import UIKit

class ViewController: UIViewController {
    @IBOutlet weak var webView:UIWebView!
    @IBOutlet weak var label:UILabel!
    
    var currentUri:String = ""
    var last_welcome:String = ""
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    
    override func viewDidAppear(animated: Bool) {
        // Login as anonymous and when the authentication has completed, start bluetooth.
        MTOneSharedInstance.apiKey = "YOUR API KEY"
        MTOneSharedInstance.autoConfigure = true
        
        label.text = "Logging In"
        
        MTOneSharedInstance.authLogin("anonymous", password: "") { (response) -> Void in
            if response.success == true {
                self.label.text = "Scanning"
                // This is the primary notification.  It is sent to the client after a valid beacon was detected.
                NSNotificationCenter.defaultCenter().addObserver(self, selector: "proximtyGetSuccess:", name: "proximtyGetSuccess", object: nil)
                
                NSNotificationCenter.defaultCenter().addObserver(self, selector: "beaconUpdated:", name: "beaconUpdated", object: nil)

                MTOneSharedInstance.callProximityListAndStartBluetooth()
            } else {
                self.label.text = "Could not login. Check your API key."
            }
        }
    }

    
    internal func beaconUpdated(notif:NSNotification) {
        var message:String = "Major: \(MTOneSharedInstance.nearestBeacon?.major) Minor: \(MTOneSharedInstance.nearestBeacon?.minor) RSSI: \(MTOneSharedInstance.nearestBeacon?.rssi) Proximity: " + MTOneSharedInstance.getBeaconProximityAsString(MTOneSharedInstance.nearestBeacon!) + " Accuracy:  \(MTOneSharedInstance.nearestBeacon?.accuracy)"
        
        let welcome = MTOneSharedInstance.getInfoValueForKey("place_welcome")
        
        if welcome != "" {
            if welcome != last_welcome {
                if MTOneSharedInstance.isRunningInBackground() == true {
                    MTOneSharedInstance.sendLocalNotification(welcome)
                } else {
                    MTOneSharedInstance.showAlertWithOK("Welcome", message: welcome)
                }
                last_welcome = welcome
            }
        }
        
        label.text = message
    }
    

    // This is called by GCD when a new beacon was seen and proximity data is available
    internal func proximtyGetSuccess(notif:NSNotification) {
        dispatch_async(dispatch_get_main_queue(), {
            let actions:Dictionary<String, JSON> = MTOneSharedInstance.getActionsForNearestBeacon()
            
            if actions.isEmpty == false {
                MTOneSharedInstance.sendNearestBeaconAsLocalNotification()
                
                for (k, action) in actions {
                    if let mime_type = action["mime_type"].asString {
                        println(mime_type)
                        if mime_type == "text/html" {
                            if let uri = action["uri"].asString {
                                self.openWebPage(uri)
                            }
                        }
                    }
                }
            }
        })
    }
    
    
    // This method displays the content of the webpage that was found in the beacon
    internal func openWebPage(uri: String) {
        if uri == "" {
            return
        }
        
        // Don't reload this page.
        if uri == self.currentUri {
            return
        }

        self.currentUri = uri
        
        self.webView.mediaPlaybackRequiresUserAction = false
        
        let url:NSURL = NSURL(string: uri)!
        let request:NSURLRequest = NSURLRequest(URL: url)
        self.webView.loadRequest(request)
    }
}

